/*
 * module.h
 *
 * Copyright 2007-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BDEVID_MODULE_H
#define BDEVID_MODULE_H 1

#include <stdint.h>
#include <sys/types.h>

/* the API for a module */

struct bdevid_module;
struct bdevid_probe_ops;

typedef int (*bdevid_register_func)(struct bdevid_module *,
    struct bdevid_probe_ops *);

struct bdevid_module_ops {
    u_int32_t magic;
    char *name;
    int (*init)(struct bdevid_module *, bdevid_register_func);
};
#define BDEVID_MAGIC 0x07d007f0
#define BDEVID_MODULE_VERSION 2
#define BDEVID_MODULE(__ops) \
    struct bdevid_module_ops *bdevid_module_ops = & (__ops); \
    uint32_t bdevid_module_version = BDEVID_MODULE_VERSION

struct bdevid_probe_ops {
    char *name;
    int (*get_vendor)(struct bdevid_bdev *bdev, char **vendor, void **priv);
    int (*get_model)(struct bdevid_bdev *bdev, char **model, void **priv);
    int (*get_unique_id)(struct bdevid_bdev *bdev, char **id, void **priv);
    void (*destroy_priv)(void *priv);
};

#endif /* BDEVID_MODULE_H */

/*
 * vim:ts=8:sw=4:sts=4:et
 */
