/*
 * block.h -- functions for dealing with block devices.
 *
 * Copyright 2006-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef NASH_BLOCK_H
#define NASH_BLOCK_H 1

#ifdef _GNU_SOURCE
#define _GNU_SOURCE_DEFINED
#else
#define _GNU_SOURCE 1
#endif

#include <sys/stat.h>

struct nash_block_dev;
extern void nashBlockInit(nashContext *);
extern void nashBlockFinish(nashContext *);

extern char *nashFindFsByLabel(nashContext *, const char *label);
extern char *nashFindFsByUUID(nashContext *, const char *uuid);
extern char *nashFindFsByName(nashContext *, const char *name);
extern char *nashFindDeviceByDevno(nashContext *, dev_t devno);

extern int nashParseSysfsDevno(const char *path, dev_t *dev);

extern int nashDisablePartitions(const char *devname);

extern int nashMkPathBySpec(nashContext *c, const char *spec, const char *path);
extern char *nashAGetPathBySpec(nashContext *c, const char * spec);
#define nashGetPathBySpec(_ctx, _spec) ({       \
        char *_ret0, *_ret1 = NULL;             \
        _ret0 = nashAGetPathBySpec(_ctx, _spec);\
        if (_ret0) {                            \
            _ret1 = strdupa(_ret0);             \
            free(_ret0);                        \
        }                                       \
        _ret1;                                  \
    })

extern void nashBdevFreePtr(struct nash_block_dev **);
extern void nash_bdev_destroy(struct nash_block_dev *);
extern struct nash_block_dev *nashBdevDup(struct nash_block_dev *);
int nashBdevCmp(struct nash_block_dev *a, struct nash_block_dev *b);

typedef struct nash_block_dev_iter *nashBdevIter;

extern nashBdevIter nashBdevIterNewPoll(nashContext *,
        struct timespec *timeout);
#define nashBdevIterNew(nc) nashBdevIterNewPoll(nc, NULL)
extern void nashBdevIterEnd(nashBdevIter *iter);
extern int nashBdevIterNext(nashBdevIter *iter, struct nash_block_dev **dev);
extern int nashBdevRemovable(struct nash_block_dev *bdev);

#ifndef _GNU_SOURCE_DEFINED
#undef _GNU_SOURCE
#else
#undef _GNU_SOURCE_DEFINED
#endif

#endif /* NASH_BLOCK_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
