/*
 * uevent.h -- reads uevents from the kernel
 *
 * Copyright 2006-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef NASH_UEVENT_H
#define NASH_UEVENT_H 1

#ifdef _GNU_SOURCE
#define _GNU_SOURCE_DEFINED
#else
#define _GNU_SOURCE 1
#endif

#include <sys/poll.h>
#include <time.h>

typedef struct nash_uevent_handler *nashUEventHandler;

typedef struct nash_uevent {
    char *msg;
    char *path;
    char *envz;
    size_t envz_len;
} nashUEvent;

extern struct nash_uevent_handler *nashUEventHandlerNew(nashContext *);
extern int nashGetUEventPoll(nashContext *nc,
        struct timespec *timeout, nashUEvent *uevent,
        struct pollfd *, int npfds);
#define nashGetUEvent(nc, timeout, uevent) \
    nashGetUEventPoll(nc, timeout, uevent, NULL, 0)
extern void _nashUEventHandlerDestroy(nashUEventHandler *handler); 
#define nashUEventHandlerDestroy(handler) _nashUEventHandlerDestroy(&(handler))
extern int nashUEventHandlerGetFd(struct nash_uevent_handler *handler);

#ifndef _GNU_SOURCE_DEFINED
#undef _GNU_SOURCE
#else
#undef _GNU_SOURCE_DEFINED
#endif

#endif /* NASH_UEVENT_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
